@@ -14,13 +14,12 @@
 
 from queue import Queue
 from abc import abstractmethod, ABCMeta
-from threading import Thread
 
 import numpy as np
 import time
 
 from qteasy import QT_CONFIG
-from .utilfuncs import get_current_tz_datetime
+from .utilfuncs import get_current_timezone_datetime
 
 CASH_DECIMAL_PLACES = QT_CONFIG['cash_decimal_places']
 AMOUNT_DECIMAL_PLACES = QT_CONFIG['amount_decimal_places']
@@ -97,7 +96,24 @@ class Broker(object):
     """
     __metaclass__ = ABCMeta
 
-    def __init__(self):
+    # TODO: for v1.1:
+    #  重构Broker类，使Broker基类提供通用的接口，如log_in, log_out, run, transaction等
+    #  并将具体的交易所实现放在子类中，如SimulatorBroker, SimpleBroker等
+    #  重构后的Broker类应该是一个抽象类，不能直接实例化，只能通过子类实例化
+    #  重构后的Broker类提供的接口可以通用于模拟交易所和真实交易所，同时所有的接口以真实交易所的接口
+    #  为标准，模拟交易所的接口应该尽量与真实交易所的接口保持一致
+    def __init__(self, data_source=None):
+        """ 生成一个Broker对象
+
+        Parameters
+        ----------
+        data_source: DataSource or None
+            交易所的数据源，可以是数据库、API等，如果为None，则使用QT_DATA_SOURCE
+        """
+        if data_source is None:
+            from qteasy import QT_DATA_SOURCE
+            data_source = QT_DATA_SOURCE
+        self._data_source = data_source
         self.broker_name = 'BaseBroker'
         self.user_name = ''
         self.password = ''
@@ -107,12 +123,16 @@ class Broker(object):
         self.is_registered = False
 
         self.time_zone = 'local'
-        self.init_time = get_current_tz_datetime(self.time_zone).strftime('%Y-%m-%d %H:%M:%S')
+        self.init_time = get_current_timezone_datetime(self.time_zone).strftime('%Y-%m-%d %H:%M:%S')
 
         self.order_queue = Queue()
         self.result_queue = Queue()
         self.broker_messages = Queue()
 
+    @property
+    def data_source(self):
+        return self._data_source
+
     def register(self, debug=False, **kwargs):
         """ Broker对象在开始运行前的注册过程，作用是设置broker的状态为is_registered
         Override这个函数，以添加更多处理
@@ -146,10 +166,11 @@ class Broker(object):
         一个Generator，可以分批返回交易结果，直至订单处理完毕或出现错误。每一个transaction都会在单
         独的线程中运行
         """
+        from threading import Thread
         if not self.is_registered:
             raise RuntimeError(f'broker is not registered!')
         if self.debug:
-            self.post_message(f'is running...')
+            self.send_message(f'is running...')
         self.status = 'init'
         while True:
             try:
@@ -186,12 +207,12 @@ class Broker(object):
             except KeyboardInterrupt:
                 # 如果Broker被用户强制退出，处理尚未完成的交易订单
                 if self.debug:
-                    self.post_message('Broker will be stopped by user.')
+                    self.send_message('Broker will be stopped by user.')
                 self.status = 'stopped'
                 continue
             except Exception as e:
                 # 如果Broker出现异常，打印异常信息，并继续运行
-                self.post_message(f'Runtime exception: {e}, please check system log for details')
+                self.send_message(f'Runtime exception: {e}, please check system log for details')
                 if self.debug:
                     import traceback
                     traceback.print_exc()
@@ -199,14 +220,24 @@ class Broker(object):
 
         return
 
-    def post_message(self, message: str, new_line=True):
+    def send_message(self, message: str, new_line=True):
         """ 将消息放入broker的消息队列
         """
-        message = f'<{self.broker_name}>: {message}'
+        if self.debug:
+            message = f'[DEBUG]-{message}'
+        message = f'[{self.broker_name}]: {message}'
         if not new_line:
             message += '_R'
         self.broker_messages.put(message)
 
+    def _submit_order(self, order):
+        """
+
+        :param order:
+        :return:
+        """
+        pass
+
     def _parse_order(self, order):
         """ 解析交易订单，提取其关键信息，并将order的状态改为"submitted"
 
@@ -233,14 +264,13 @@ class Broker(object):
         """
 
         if self.debug:
-            self.post_message(f'_get_result():\nsubmit order components of order(ID) {order["order_id"]}:\n'
+            self.send_message(f'_parse_order():\nsubmit order components of order(ID) {order["order_id"]}:\n'
                               f'quantity:{order["qty"]}\norder_price={order["price"]}\n'
                               f'order_direction={order["direction"]}\n')
         pos_id = order['pos_id']
         from qteasy.trade_recording import get_position_by_id
-        from qteasy import QT_DATA_SOURCE
         try:
-            position = get_position_by_id(pos_id=pos_id, data_source=QT_DATA_SOURCE)
+            position = get_position_by_id(pos_id=pos_id, data_source=self.data_source)
         except RuntimeError as e:
             raise RuntimeError(e)
         symbol = position['symbol']
@@ -294,7 +324,7 @@ class Broker(object):
 
             # 确认数据格式正确后，将数据圆整到合适的精度，并组装为raw_trade_result
             if self.debug:
-                self.post_message(f'method: _get_result(): got transaction result for order(ID) {order["order_id"]}\n'
+                self.send_message(f'method: _get_result(): got transaction result for order(ID) {order["order_id"]}\n'
                                   f'result_type={result_type}, \nqty={qty}, \n'
                                   f'filled_price={filled_price}, \nfee={fee}')
             # 圆整qty、filled_qty和fee
@@ -311,7 +341,7 @@ class Broker(object):
             else:
                 raise ValueError(f'Unknown result_type: {result_type}, should be one of ["filled", "canceled"]')
 
-            current_datetime = get_current_tz_datetime(self.time_zone)
+            current_datetime = get_current_timezone_datetime(self.time_zone)
             raw_trade_result = {
                 'order_id':        order['order_id'],
                 'filled_qty':      filled_qty,
@@ -325,13 +355,15 @@ class Broker(object):
 
             # 将trade_result放入result_queue
             if self.debug:
-                self.post_message(f'method _get_result(): created raw trade result for order(ID) {order["order_id"]}:\n'
+                self.send_message(f'method _get_result(): created raw trade result for order(ID) {order["order_id"]}:\n'
+
                                   f'{raw_trade_result}')
             self.result_queue.put(raw_trade_result)
 
         # 全部订单处理完毕或发生错误后结束
         return
 
+
     @abstractmethod
     def transaction(self, symbol, order_qty, order_price, direction, position='long', order_type='market'):
         """ 交易所处理交易订单并获取交易结果, 抽象方法，需要由用户在子类中实现
@@ -403,8 +435,8 @@ class SimpleBroker(Broker):
     ----------
     """
 
-    def __init__(self):
-        super(SimpleBroker, self).__init__()
+    def __init__(self, data_source=None):
+        super(SimpleBroker, self).__init__(data_source=data_source)
         self.broker_name = 'SimpleBroker'
 
     def transaction(self, symbol, order_qty, order_price, direction, position='long', order_type='market'):
@@ -491,7 +523,7 @@ class SimulatorBroker(Broker):
                  delay=1.0,
                  price_deviation=0.0,
                  probabilities=(0.9, 0.08, 0.02),
-                 max_retry=100):
+                 data_source=None):
         """ 生成一个Broker对象
 
         Parameters
@@ -522,11 +554,9 @@ class SimulatorBroker(Broker):
             卖出报价小于100+1元即可成交
         probabilities: tuple of 3 floats, default (0.90, 0.08, 0.02)
             模拟完全成交、部分成交和未成交三种情况出现的概率
-        max_retry: int
-            网络故障或价格不匹配无法成交的最大重试次数，超过后返回cancel结果
 
         """
-        super(SimulatorBroker, self).__init__()
+        super(SimulatorBroker, self).__init__(data_source=data_source)
         self.broker_name = 'SimulatorBroker'
         self.fee_rate_buy = fee_rate_buy
         self.fee_rate_sell = fee_rate_sell
@@ -540,14 +570,12 @@ class SimulatorBroker(Broker):
         self.delay = delay
         self.price_deviation = price_deviation
         self.probabilities = probabilities
-        self.max_retry = max_retry
 
     def transaction(self, symbol, order_qty, order_price, direction, position='long', order_type='market'):
         """ 读取实时价格模拟成交结果
         """
 
         total_filled = 0
-        retry = self.max_retry
 
         while True:
 
@@ -564,6 +592,7 @@ class SimulatorBroker(Broker):
                 continue
 
             # 获取当前实时价格
+            retry = 0
             from .emfuncs import stock_live_kline_price
             live_prices = stock_live_kline_price(symbol, freq='D', verbose=True, parallel=False)
             if not live_prices.empty:
@@ -572,7 +601,7 @@ class SimulatorBroker(Broker):
                 live_price = live_prices.close.iloc[-1]
                 price_deviation = live_price * self.price_deviation
             else:  # 实时价格获取不成功，稍后重试
-                self.post_message(f'live price of {symbol} can not be acquired at the moment, '
+                self.send_message(f'live price of {symbol} can not be acquired at the moment, '
                                   f'order will not be processed, retries left: {retry}')
                 retry -= 1
                 live_price = 0
@@ -580,24 +609,23 @@ class SimulatorBroker(Broker):
                 price_deviation = 0
                 if retry > 0:
                     continue
-
             # 重试超过max_retry，直接cancel订单
             if retry <= 0:
-                self.post_message(f'order will be canceled because max retries exceeded')
+                self.send_message(f'order will be canceled because max retries exceeded')
                 result_type = 'canceled'
             # 如果当前价高于挂卖价(允许误差由price_deviation控制)，大概率成交或部分成交
-            elif (live_price >= order_price - price_deviation) and (direction == 'sell'):
+            if (live_price >= order_price - price_deviation) and (direction == 'sell'):
                 result_type = np.random.choice(['filled', 'partial-filled', 'canceled'], p=self.probabilities)
                 # 如果change非常接近-10%(跌停)，则非常大概率canceled
                 if abs(change + 0.1) <= 0.001:
-                    self.post_message(f'order will be probably canceled because -10% sell-limit')
+                    self.send_message(f'order will be probably canceled because -10% sell-limit')
                     result_type = np.random.choice(['filled', 'partial-filled', 'canceled'], p=(0.01, 0.01, 0.98))
             # 如果当前价低于挂买价(允许误差由price_deviation控制), 大概率成交或部分成交
             elif (live_price <= order_price + price_deviation) and (direction == 'buy'):
                 result_type = np.random.choice(['filled', 'partial-filled', 'canceled'], p=self.probabilities)
                 # 如果change非常接近+10%(涨停)，则非常大概率canceled
                 if abs(change - 0.1) <= 0.001:
-                    self.post_message(f'order will be probably canceled because +10% buy-limit')
+                    self.send_message(f'order will be probably canceled because +10% buy-limit')
                     result_type = np.random.choice(['filled', 'partial-filled', 'canceled'], p=(0.01, 0.01, 0.98))
             # 如果挂单类型为市价单且不受张跌停限制, 大概率成交或部分成交
             elif (order_type == 'market') and (-0.098 < change < 0.098):
@@ -606,7 +634,7 @@ class SimulatorBroker(Broker):
             # 所有条件均不满足，稍后重试
             else:
                 if self.debug:
-                    self.post_message(f'current price does not satisfy quoted, retries left: {retry}')
+                    self.send_message(f'current price does not satisfy quoted, retries left: {retry}')
                 retry -= 1
                 continue
 
@@ -663,8 +691,8 @@ class NotImplementedBroker(Broker):
     """ NotImplementedBroker raises NotImplementedError when __init__() is called
     """
 
-    def __init__(self):
-        super(NotImplementedBroker, self).__init__()
+    def __init__(self, data_source=None):
+        super(NotImplementedBroker, self).__init__(data_source=data_source)
         raise NotImplementedError('NotImplementedBroker is not implemented yet')
 
     def transaction(self, symbol, order_qty, order_price, direction, position='long', order_type='market'):
@@ -703,4 +731,4 @@ def get_broker(name: str = 'simulator', params=None):
     broker_func = all_brokers.get(name, SimulatorBroker)
     if params is not None:
         return broker_func(**params)
-    return broker_func()
+    return broker_func()
\ No newline at end of file
