@@ -80,16 +80,16 @@ class BaseStrategy:
             name: str = 'strategy name',
             description: str = 'intro text of strategy',
             par_count: int = None,
-            par_types: [list, str] = None,
+            par_types: [[str], str] = None,
             par_range: [list, tuple] = None,
             strategy_run_freq: str = 'd',
             sample_freq: str = None,  # to be deprecated
             strategy_run_timing: str = 'close',
             bt_price_type: str = None,  # to be deprecated
-            strategy_data_types: [str, list] = 'close',
-            data_types: [str, list] = None,  # to be deprecated
+            strategy_data_types: [str, [str]] = 'close',
+            data_types: [str, [str]] = None,  # to be deprecated
             use_latest_data_cycle: bool = True,
-            reference_data_types: [str, list] = '',
+            reference_data_types: [str, [str]] = '',
             data_freq: str = 'd',
             window_length: int = 270,
     ):
@@ -257,6 +257,7 @@ class BaseStrategy:
                 par_range = par_range[0:par_count]
 
         self._pars = None
+        self._opt_tag = None
         self.set_opt_tag(opt_tag)  # 策略的优化标记，
         self._stg_type = stg_type  # 策略类型
         self._stg_name = name  # 策略的名称
@@ -396,7 +397,9 @@ class BaseStrategy:
 
     @property
     def pars(self):
-        """策略参数，元组"""
+        """策略参数，元组
+        :return:
+        """
         return self._pars
 
     @pars.setter
@@ -579,7 +582,7 @@ class BaseStrategy:
         str2 = f'{self.name})'
         return ''.join([str1, str2])
 
-    def info(self, verbose: bool = True, stg_id=None):
+    def info(self, verbose: bool = True, stg_id: str = None) -> None:
         """打印所有相关信息和主要属性
 
         Parameters
@@ -649,12 +652,17 @@ class BaseStrategy:
             return 1
         if isinstance(pars, dict):
             return self.set_dict_pars(pars)
+
+        # try correct par types
+        pars = self.correct_pars_type(pars)
         # now pars should be tuples
         if self.check_pars(pars):
             self._pars = pars
             return 1
+        else:
+            return 0
 
-    def check_pars(self, pars):
+    def check_pars(self, pars: tuple) -> bool:
         """检查pars(一个tuple)是否符合strategy的参数设置"""
         for par, par_type, par_range in zip(pars, self._par_types, self.par_range):
             if not isinstance(pars, tuple):
@@ -665,17 +673,13 @@ class BaseStrategy:
                                  f' got {len(pars)} ({pars}).')
             if par_type in ['int', 'discr']:
                 # 如果par_type是int或者discr，那么par应该是一个整数
-                try:
-                    par = int(par)
-                except Exception:
-                    raise Exception(f'Invalid parameter, {par} can not be converted to an integer')
+                if not isinstance(par, int):
+                    raise Exception(f'Invalid parameter, it should be an integer, got {type(par)}')
 
             if par_type in ['float', 'conti']:
-                # 如果par_type是float或者conti，那么par应该是一个浮点数
-                try:
-                    par = float(par)
-                except Exception:
-                    raise Exception(f'Invalid parameter, {par} can not be converted to a float number')
+                # 如果par_type是float或者conti，那么par应该是一个浮点数/整数
+                if not isinstance(par, (int, float)):
+                    raise Exception(f'Invalid parameter, it should be a float or an integer, got {type(par)}')
 
             if par_type in ['enum']:
                 # 如果par_type是enum，那么par应该是par_range中的一个元素
@@ -688,6 +692,41 @@ class BaseStrategy:
                     raise ValueError(f'Invalid parameter! {par} is out of range: ({l_bound} - {u_bound})')
         return True
 
+    def correct_pars_type(self, pars: tuple) -> tuple:
+        """ 将可能为字符串格式的pars根据type调整为正确的格式
+
+        Parameters
+        ----------
+        pars: tuple
+            策略参数
+
+        Returns
+        -------
+        pars: tuple
+            pars in corrected type
+        """
+
+        if len(pars) != self._par_count:
+            raise ValueError(f'Invalid strategy parameter, expect {self.par_count} parameters,'
+                             f' got {len(pars)} ({pars}).')
+        # corrected_pars = [None] * self._par_count
+        corrected_pars = [None for _ in range(self._par_count)]
+        try:
+            for i in range(self._par_count):
+                par = pars[i]
+                p_type = self.par_types[i]
+                if p_type in ['int', 'descr']:
+                    corrected_pars[i] = int(par)
+                elif p_type in ['float', 'conti']:
+                    corrected_pars[i] = float(par)
+                else:
+                    corrected_pars[i] = par
+
+            return tuple(corrected_pars)
+
+        except Exception as e:
+            raise RuntimeError({e})
+
     def set_dict_pars(self, pars: dict) -> int:
         """ 当策略参数是一个dict的时候，这个dict的key是股票代码，values是每个股票代码的不同策略参数，每个策略参数都应该符合
             检查dict的合法性，并设置参数
@@ -696,7 +735,7 @@ class BaseStrategy:
         if not isinstance(pars, dict):
             raise TypeError(f'Invalid parameter, expect a dict, got {type(pars)}')
         if len(pars) == 0:
-            return self.set_pars(pars=None)
+            return self.set_pars(None)
         for key in pars.keys():
             if not isinstance(key, str):
                 raise TypeError(f'Invalid parameter, all keys of dict type parameter should be a stock code,'
@@ -705,7 +744,7 @@ class BaseStrategy:
             self._pars = pars
             return 1
 
-    def update_pars(self, pars):
+    def update_pars(self, pars: (tuple, dict)) -> None:
         """ 极简方式更新策略的参数，默认参数格式正确，不检查参数的合规性"""
         self._pars = pars
 
@@ -725,13 +764,13 @@ class BaseStrategy:
         return par_range
 
     def set_hist_pars(self,
-                      data_freq=None,
-                      strategy_run_freq=None,
-                      window_length=None,
-                      strategy_data_types=None,
-                      strategy_run_timing=None,
-                      reference_data_types=None,
-                      use_latest_data_cycle=None):
+                      data_freq: str = None,
+                      strategy_run_freq: str = None,
+                      window_length: int = None,
+                      strategy_data_types: str = None,
+                      strategy_run_timing: str = None,
+                      reference_data_types: str = None,
+                      use_latest_data_cycle: bool = None) -> None:
         """ 设置策略的历史数据回测相关属性
 
         Parameters
@@ -845,7 +884,7 @@ class BaseStrategy:
     def generate(self,
                  hist_data: np.ndarray,
                  ref_data: np.ndarray = None,
-                 trade_data: np.ndarray = None,
+                 trade_data: np.ndarray = None,  # deprecated since v1.1
                  data_idx=None):
         """策略类的抽象方法，接受输入历史数据并根据参数生成策略输出
 
@@ -855,8 +894,8 @@ class BaseStrategy:
             策略运行所需的历史数据，包括价格数据、指标数据等
         ref_data: np.ndarray
             策略运行所需的参考数据，包括价格数据、指标数据等
-        trade_data: np.ndarray
-            策略运行所需的交易数据，包括价格数据、指标数据等
+        trade_data: np.ndarray  # deprecated since v1.1
+            策略运行所需的交易数据，包括价格数据、指标数据等  # TODO (v1.1 Deprecate, v1.2 删除)
         data_idx: int or np.ndarray
             策略运行所需的历史数据的索引，用于在历史数据中定位当前运行的数据
 
@@ -865,6 +904,16 @@ class BaseStrategy:
         stg_signal: np.ndarray
             策略运行的输出，包括交易信号、交易指令等
         """
+
+        # TODO: for v1.1规划更新
+        #  改变trade_data的定义。删除trade_data，允许用户在hist_data和ref_data
+        #  中定义持仓量、成交量、成交价等数据，这些数据类型通过特殊的数据类型关键字指定，因此客户在策略定
+        #  义时可以通过data_type来灵活地指定所需的数据，不需要专门的trade_data数据类型了。
+        #  同时，这样做还有一个好处，可以定义更多更广泛的数据类型，例如交易日日期、星期几、月份、交易时间
+        #  等等数据，所有与股票无关的数据都可以定义为reference_data，与股票相关的数据可以定义为
+        #  history_data。这样可以大大增加策略的灵活性。
+        #  同时为未来允许用户自定义数据类型做好准备。
+
         # 所有的参数有效性检查都在strategy.ready 以及 operator层面执行
         # 在这里根据data_idx的类型，生成一组交易信号，或者一张完整的交易信号清单
         if data_idx is None:
@@ -882,8 +931,7 @@ class BaseStrategy:
             else:
                 ref_seg = ref_data[idx]
             return self.generate_one(h_seg=h_seg, ref_seg=ref_seg, trade_data=trade_data)
-        elif isinstance(data_idx, np.ndarray):
-            # 如果data_idx为一组整数时，生成完整信号清单 signal_list
+        elif isinstance(data_idx, np.ndarray):  # 如果data_idx为一组整数时，生成完整信号清单 signal_list
             # 一个空的ndarray对象用于存储生成的选股蒙版，全部填充值为np.nan
             signal_count, share_count, date_count, htype_count = hist_data.shape
             sig_list = np.full(shape=(signal_count, share_count), fill_value=np.nan, order='C')
@@ -895,6 +943,7 @@ class BaseStrategy:
             else:
                 ref_data_list = ref_data[data_idx]
             if trade_data is None:
+                # warnings.warn('trade_data is deprecated, use hist_data and ref_data instead', DeprecationWarning)
                 trade_data_list = all_none_list
             else:
                 trade_data_list = [trade_data] * signal_count
@@ -917,7 +966,7 @@ class BaseStrategy:
             策略运行所需的历史数片段，包括价格数据、指标数据等
         ref_seg: np.ndarray
             策略运行所需的参考数片段，包括价格数据、指标数据等
-        trade_data: np.ndarray
+        trade_data: np.ndarray  depreciated since v1.1
             策略运行所需的交易数据片段，包括价格数据、指标数据等
 
         Returns
@@ -1762,13 +1811,10 @@ class RuleIterator(BaseStrategy):
         else:
             ref_nonan = ref_seg[~np.isnan(ref_seg[:, 0])]
 
-        try:
-            return self.realize(h=hist_nonan,
-                                r=ref_nonan,
-                                t=trade_data,
-                                pars=params)
-        except Exception:
-            return np.nan
+        return self.realize(h=hist_nonan,
+                            r=ref_nonan,
+                            t=trade_data,
+                            pars=params)
 
     @abstractmethod
     def realize(self,
@@ -1779,4 +1825,4 @@ class RuleIterator(BaseStrategy):
         """ h_seg和ref_seg都是用于生成交易信号的一段窗口数据，根据这一段窗口数据
             生成一个股票的独立交易信号，同样的规则会被复制到其他股票
         """
-        pass
\ No newline at end of file
+        pass
