@@ -22,9 +22,9 @@ TIMEZONE = 'Asia/Shanghai'
 
 
 # TODO: 创建一个模块级变量，用于存储交易信号的数据源，所有的交易信号都从这个数据源中读取
-#  避免交易信号从不同的数据源中获取，导致交易信号的不一致性
+#  避免交易信号从不同的数据源中获取，导致交易信号的不一致性 ?? 这是不是最好的做法？？
 # 9 foundational functions for account and position management
-def new_account(user_name, cash_amount, data_source=None, **account_data):
+def new_account(user_name, cash_amount, data_source=None, **account_data) -> int:
     """ 创建一个新的账户
 
     Parameters
@@ -63,10 +63,35 @@ def new_account(user_name, cash_amount, data_source=None, **account_data):
             },
             **account_data,
     )
-    return account_id
+    return int(account_id)
 
 
-def get_account(account_id, user_name=None, data_source=None):
+def get_all_accounts(data_source=None) -> pd.DataFrame:
+    """ 获取所有的账户
+
+    Parameters
+    ----------
+    data_source: str, optional
+        数据源的名称, 默认为None, 表示使用默认的数据源
+
+    Returns
+    -------
+    accounts: pandas.DataFrame
+        所有账户的信息
+    """
+
+    import qteasy as qt
+    if data_source is None:
+        data_source = qt.QT_DATA_SOURCE
+    if not isinstance(data_source, qt.DataSource):
+        raise TypeError(f'data_source must be a DataSource instance, got {type(data_source)} instead')
+
+    accounts = data_source.read_sys_table_data('sys_op_live_accounts')
+
+    return accounts
+
+
+def get_account(account_id, user_name=None, data_source=None) -> dict:
     """ 根据account_id, 或者user_name获取账户的信息
 
     Parameters
@@ -80,7 +105,7 @@ def get_account(account_id, user_name=None, data_source=None):
 
     Returns
     -------
-    dict: 账户的信息
+    dict: ID为account_id的账户的信息
 
     Raises
     ------
@@ -104,7 +129,7 @@ def get_account(account_id, user_name=None, data_source=None):
         return account
 
 
-def update_account(account_id, data_source=None, **account_data):
+def update_account(account_id, data_source=None, **account_data) -> None:
     """ 更新账户信息
 
     通用接口，用于更新账户的所有信息，除了账户的持仓和可用资金
@@ -133,7 +158,7 @@ def update_account(account_id, data_source=None, **account_data):
     data_source.update_sys_table_data('sys_op_live_accounts', record_id=account_id, **account_data)
 
 
-def update_account_balance(account_id, data_source=None, **cash_change):
+def update_account_balance(account_id, data_source=None, **cash_change) -> None:
     """ 更新账户的资金总额和可用资金, 为了避免误操作，仅允许修改现金总额、可用现金和总投资额，其他字段不可修改
 
     Parameters
@@ -190,11 +215,6 @@ def update_account_balance(account_id, data_source=None, **cash_change):
     if cash_amount < 0:
         raise RuntimeError(f'cash_amount cannot be less than 0!')
 
-    # debug
-    # print(f'[DEBUG]: update account balance for id: {account_id} \n'
-    #       f'cash_amount: {account_data["cash_amount"]} -> {cash_amount}, \n'
-    #       f'available_cash: {account_data["available_cash"]} -> {available_cash} \n'
-    #       f'total_investment: {account_data["total_invest"]} -> {total_investment}')
     # 更新账户的资金总额和可用资金
     data_source.update_sys_table_data(
             'sys_op_live_accounts',
@@ -205,6 +225,80 @@ def update_account_balance(account_id, data_source=None, **cash_change):
     )
 
 
+def delete_account(account_id: int, data_source=None) -> None:
+    """ 删除账户，删除账户时，需要同时删除账户的持仓和交易信号。如果账户不存在，则直接返回None
+    在删除账户时，同时删除账户的持仓和交易信号，如果删除账户的持仓或交易信号失败，则会回滚删除操作
+
+    Parameters
+    ----------
+    account_id: int
+        账户的id
+    data_source: DataSource, optional
+        进行操作的数据源, 默认为None, 表示使用默认的数据源
+
+    Returns
+    -------
+    None
+    """
+
+    if data_source is None:
+        import qteasy as qt
+        data_source = qt.QT_DATA_SOURCE
+    if not isinstance(data_source, DataSource):
+        msg = f'data_source must be a DataSource instance, got {type(data_source)} instead'
+        raise TypeError(msg)
+
+    # 检查account_id是否存在，如果不存在，则直接返回None
+    account = get_account(account_id, data_source=data_source)
+    if account is None:
+        # Nothing is deleted
+        return None
+
+    # 找出与account_id相关的所有持仓和交易订单记忆交易结果
+    positions = get_account_positions(account_id, data_source=data_source)
+    pos_ids = positions.index.tolist() if not positions.empty else []
+    orders = query_trade_orders(account_id=account_id, data_source=data_source)
+    order_ids = orders.index.tolist() if not orders.empty else []
+    results = read_trade_results_by_order_id(order_id=order_ids, data_source=data_source)
+    result_ids = results.index.tolist() if not results.empty else []
+
+    # 临时保留将要操作的完整数据表，以便回滚
+    account_table_data = data_source.read_sys_table_data('sys_op_live_accounts')
+    position_table_data = data_source.read_sys_table_data('sys_op_positions')
+    order_table_data = data_source.read_sys_table_data('sys_op_trade_orders')
+    result_table_data = data_source.read_sys_table_data('sys_op_trade_results')
+
+    # 开始删除数据：
+    print(f'Deleting account {account_id} ...')
+    print(f'Following records will be deleted: \n'
+          f'account: {account_id}\n'
+          f'positions: {pos_ids}\n'
+          f'orders: {order_ids}\n'
+          f'results: {result_ids}')
+    try:
+        # 删除账户
+        data_source.delete_sys_table_data('sys_op_live_accounts', record_ids=[account_id])
+        # 删除持仓
+        data_source.delete_sys_table_data('sys_op_positions', record_ids=pos_ids)
+        # 删除交易信号
+        data_source.delete_sys_table_data('sys_op_trade_orders', record_ids=order_ids)
+        # 删除交易结果
+        data_source.delete_sys_table_data('sys_op_trade_results', record_ids=result_ids)
+    except Exception as e:
+        # 如果删除失败，则回滚删除操作
+        data_source.drop_table_data('sys_op_live_accounts')
+        data_source.drop_table_data('sys_op_positions')
+        data_source.drop_table_data('sys_op_trade_orders')
+        data_source.drop_table_data('sys_op_trade_results')
+        data_source.write_table_data(account_table_data, 'sys_op_live_accounts')
+        data_source.write_table_data(position_table_data, 'sys_op_positions')
+        data_source.write_table_data(order_table_data, 'sys_op_trade_orders')
+        data_source.write_table_data(result_table_data, 'sys_op_trade_results')
+        import warnings
+        msg = f'Error occurred: {e}, delete account failed, rollback to previous state!'
+        warnings.warn(msg, RuntimeWarning)
+
+
 def get_position_by_id(pos_id, data_source=None):
     """ 通过pos_id获取持仓的信息
 
@@ -855,7 +949,7 @@ def query_trade_orders(account_id,
     return pd.concat(res)
 
 
-# 2 2nd level functions for trade signal
+# 2 2nd level functions for trade signal TODO: (maybe) move to trading_util.py
 def read_trade_order_detail(order_id, data_source=None):
     """ 从数据库中读取交易信号的详细信息，包括从关联表中读取symbol和position的信息
 
@@ -1112,15 +1206,15 @@ def read_trade_results_by_order_id(order_id, data_source=None):
     -------
     trade_results: pd.DataFrame, columns=['order_id', 'filled_qty', 'price', 'transaction_fee', 'execution_time',
                         'canceled_qty', 'delivery_amount', 'delivery_status']
-    交易结果:
-    order_id: int 交易信号的id
-    filled_qty: int 成交数量
-    price: float 成交价格
-    transaction_fee: float 交易费用
-    execution_time: datetime.datetime 成交时间
-    canceled_qty: int 撤单数量
-    delivery_amount: float 交割金额
-    delivery_status: str 交割状态
+    交易结果, 包含以下列:
+        - order_id: int 交易信号的id
+        - filled_qty: int 成交数量
+        - price: float 成交价格
+        - transaction_fee: float 交易费用
+        - execution_time: datetime.datetime 成交时间
+        - canceled_qty: int 撤单数量
+        - delivery_amount: float 交割金额
+        - delivery_status: str 交割状态
     """
     if not isinstance(order_id, (int, np.int64, np.ndarray, list, )):
         raise TypeError(f'order_id must be an integer, a list of integers or a numpy array of integers, '
