@@ -755,11 +755,6 @@ def cancel_order(order_id, data_source=None, config=None):
             order_details['qty'] - total_filled_qty,
             AMOUNT_DECIMAL_PLACES,
     )
-    # debug
-    # print(f'[DEBUG]: canceling order {order_id}, order result:\n {order_results}\n'
-    #       f'total filled qty: {total_filled_qty}\n'
-    #       f'already canceled qty: {already_canceled_qty}\n'
-    #       f'remaining qty: {remaining_qty}\n')
 
     if remaining_qty <= 0:
         raise RuntimeError(f'order status wrong: remaining qty should be larger than 0'
@@ -780,7 +775,7 @@ def cancel_order(order_id, data_source=None, config=None):
     )
 
 
-def process_account_delivery(account_id, data_source=None, config=None):
+def process_account_delivery(account_id, data_source=None, config=None) -> list:
     """ 处理account_id账户中所有持仓和现金的交割
 
     从交易历史中读取尚未交割的现金和持仓，根据config中的设置值 'cash_delivery_period' 和
@@ -798,8 +793,8 @@ def process_account_delivery(account_id, data_source=None, config=None):
 
     Returns
     -------
-    list_of_delivery_result: list of dict,
-        以列表形式返回的所有有效交割结果
+    delivery_result: list
+        包含所有交割结果的列表
     """
 
     if not isinstance(account_id, (int, np.int64)):
@@ -929,9 +924,11 @@ def deliver_trade_result(result_id, account_id, result=None, stock_delivery_peri
         delivery_result['updated_qty'] = position['available_qty']
 
     elif trade_direction == 'sell':
+        position_id = order_detail['pos_id']
         delivery_result['account_id'] = account_id
         account = get_account(account_id, data_source=data_source)
         delivery_result['order_id'] = order_id
+        delivery_result['pos_id'] = position_id
         delivery_result['prev_amount'] = account['available_cash']
         update_account_balance(
                 account_id=account_id,
@@ -961,7 +958,8 @@ def process_trade_result(raw_trade_result, data_source=None, config=None):
     Parameters
     ----------
     raw_trade_result: dict
-        原始交易结果, 与正式交易结果的区别在于，原始交易结果不包含execution_time字段
+        原始交易结果, 与正式交易结果的区别在于，原始交易结果不包含execution_time字段，
+        原始交易结果是尚未确认的交易结果，只有确认有足够的现金和持仓时才能确认交易结果
     data_source: str, optional
         数据源的名称, 默认为None, 表示使用默认的数据源
     config: dict, optional
@@ -970,8 +968,9 @@ def process_trade_result(raw_trade_result, data_source=None, config=None):
     Returns
     -------
     result_id: int
-        交易结果的id
+        交易结果的ID
     """
+    # TODO: 一个函数只做一件事情，我感觉这个函数太长了
 
     if not isinstance(raw_trade_result, dict):
         raise TypeError(f'raw_trade_result must be a dict, got {type(raw_trade_result)} instead')
@@ -1030,18 +1029,13 @@ def process_trade_result(raw_trade_result, data_source=None, config=None):
                 raw_trade_result['filled_qty'] * raw_trade_result['price'] - raw_trade_result['transaction_fee'],
                 CASH_DECIMAL_PLACES,
         )
-        # print(f'[DEBUG]: in process_trade_result(): selling stock, position_change: {position_change}\n'
-        #       f'cash_change = {raw_trade_result["filled_qty"]} * {raw_trade_result["price"]} - '
-        #       f'{raw_trade_result["transaction_fee"]} = {cash_change}, ')
+
     elif order_detail['direction'] == 'buy':
         position_change = raw_trade_result['filled_qty']
         cash_change = np.round(
                 - raw_trade_result['filled_qty'] * raw_trade_result['price'] - raw_trade_result['transaction_fee'],
                 CASH_DECIMAL_PLACES,
         )
-        # print(f'[DEBUG]: in process_trade_result(): buying stock, position_change: {position_change}\n'
-        #       f'cash_change = - {raw_trade_result["filled_qty"]} * {raw_trade_result["price"]} - '
-        #       f'{raw_trade_result["transaction_fee"]} = {cash_change}, ')
     else:  # for any other unexpected direction
         raise ValueError(f'Invalid direction: {order_detail["direction"]}')
 
@@ -1054,13 +1048,6 @@ def process_trade_result(raw_trade_result, data_source=None, config=None):
 
     available_cash = get_account_cash_availabilities(order_detail['account_id'], data_source=data_source)[1]
 
-    # print(f'[DEBUG]: updating account balance and position for order {order_id}...\n'
-    #       f'result: {raw_trade_result}\n'
-    #       f'position_change: {position_change}\n'
-    #       f'cash_change: {cash_change}\n'
-    #       f'available_qty: {available_qty}\n'
-    #       f'available_cash: {available_cash}\n')
-
     # 如果position_change小于available_position_amount，则抛出异常
     if available_qty + position_change < 0:
         raise RuntimeError(f'position_change {position_change} is greater than '
@@ -1088,6 +1075,11 @@ def process_trade_result(raw_trade_result, data_source=None, config=None):
     # TODO: 这里可能会有Bug：为了避免在更新账户余额和持仓时出现错误，需要将更新账户余额和持仓的操作放在一个事务中
     #  否则可能出现更新账户余额成功，但更新持仓失败的情况，或订单状态更新失败的情况
 
+    # TODO: 买入或卖出的交易结果应该只更新qty/cash
+    #  而available_qty/available_cash统一应该留到订单交易后交割时更新
+    #  （在交易后立即更新，但允许部分交割，只有完全交割后才修改状态）
+    #  这一条需要讨论，不一定合理
+
     # 如果direction为buy，则同时更新cash_amount和available_cash，如果direction为sell，则只更新cash_amount
     if order_detail['direction'] == 'buy':
         update_account_balance(
@@ -1317,15 +1309,39 @@ def _trade_time_index(start=None,
     if freq is not None:
         freq = str(freq).lower()
     # 检查时间序列区间的开闭状况
-    closed = None
+    closed = 'both'
     if include_start:
         closed = 'left'
     if include_end:
         closed = 'right'
     if include_start and include_end:
-        closed = None
+        closed = 'both'
 
-    time_index = pd.date_range(start=start, end=end, periods=periods, freq=freq, closed=closed)
+    '''
+    here temp code for parsing version of pandas
+    - if version is less than 1.4.0, use closed parameter
+    - if version is greater than 1.4.0, use inclusive parameter
+    '''
+    if pd.__version__ < '1.4.0':
+        # noinspection PyTypeChecker
+        closed = None if closed == 'both' else closed
+        time_index = pd.date_range(
+                start=start,
+                end=end,
+                periods=periods,
+                freq=freq,
+                closed=closed,
+        )
+    else:
+        # noinspection PyTypeChecker
+        time_index = pd.date_range(
+                start=start,
+                end=end,
+                periods=periods,
+                freq=freq,
+                # closed=closed,  # closed parameter is deprecated since version 1.4.0
+                inclusive=closed,  # inclusive is added inplace of closed since 1.4.0
+        )
 
     if trade_days_only:
         # 剔除time_index中的non-trade day
@@ -1341,7 +1357,11 @@ def _trade_time_index(start=None,
         if pd.isna(trade_cal.iloc[0]):
             date = pd.to_datetime(time_index[0].date())
             trade_cal.iloc[0] = calendar.loc[date]
-        trade_cal = trade_cal.fillna(method='ffill')
+
+        # Series.fillna with 'method' is deprecated and will raise in a future version. Use obj.ffill() or
+        # obj.bfill() instead.
+        # trade_cal = trade_cal.fillna(method='ffill')
+        trade_cal = trade_cal.ffill()
         time_index = trade_cal.loc[trade_cal == 1].index
 
     # 判断time_index的freq，当freq小于一天时，需要按交易时段取出部分index
@@ -1367,7 +1387,8 @@ def _trade_time_index(start=None,
         year:       A-DEC/...
         由于周、季、年三种情况存在复合字符串，因此需要split
     '''
-    if freq_str[-1:].lower() in ['t', 'h']:
+    if (freq_str[-1:].lower() in ['t', 'h']) or (freq_str[-3:] in ['min']):
+        # freq_str for min in pandas 2.0 is 'T', in pandas 2.2 is 'MIN'
         idx_am = time_index.indexer_between_time(
                 start_time=start_am,
                 end_time=end_am,
@@ -1404,7 +1425,8 @@ def get_symbol_names(datasource, symbols, asset_types: list = None, refresh: boo
     Returns
     -------
     names: list
-        股票名称列表
+        股票名称列表，如果某个名称无法获取，该列表元素为'N/A'
+        本函数不会返回空列表，除非输入的symbols为空列表
 
     Examples
     --------
@@ -1412,13 +1434,23 @@ def get_symbol_names(datasource, symbols, asset_types: list = None, refresh: boo
     ['平安银行']
     >>> get_symbol_names(datasource, ['000001.SZ', '000002.SZ'])
     ['平安银行', '万科A']
+    >>> get_symbol_names(datasource, ['no_such_symbol', '000001.SZ'])
+    ['N/A', '平安银行']
     """
+    from qteasy import DataSource, QT_DATA_SOURCE
+    if datasource is None:
+        datasource = QT_DATA_SOURCE
+    if not isinstance(datasource, DataSource):
+        raise TypeError(f'datasource must be an instance of DataSource, got {type(datasource)} instead')
 
     if isinstance(symbols, str):
         symbols = str_to_list(symbols)
     if not isinstance(symbols, list):
         raise TypeError(f'symbols must be str or list of str, got {type(symbols)} instead')
 
+    if not symbols:
+        return []
+
     if asset_types is None:
         asset_types = ['stock', 'index', 'fund', 'future', 'option']
     else:
@@ -1447,8 +1479,10 @@ def get_symbol_names(datasource, symbols, asset_types: list = None, refresh: boo
                 all_data_types[asset_type.lower()] for asset_type in asset_types
             ),
     )
+    if all_basics.empty:
+        return ['N/A'] * len(symbols)
     try:
-        names_found = all_basics.reindex(index=symbols).name.tolist()
+        names_found = all_basics.reindex(index=symbols)["name"].tolist()
     except Exception as e:
         raise RuntimeError(f'Error in get_symbol_names(): {e}')
     # replace all nan with 'N/A'
