@@ -9,16 +9,19 @@
 # ======================================
 
 import argparse
-import numpy as np
-import pandas as pd
-import sys
 import re
-import qteasy
+import shutil
+import sys
 import time
 import warnings
+import numpy as np
+import pandas as pd
+
 from numba import njit
 from functools import wraps, lru_cache
 
+import qteasy
+
 TIME_FREQ_LEVELS = {
     'Y':      10,
     'Q':      20,
@@ -96,6 +99,7 @@ def get_qt_argparser():
     parser.add_argument('-r', '--restart', action='store_true', default=False,
                         help='if set, remove all record and restart account')
     parser.add_argument('-d', '--debug', action='store_true', help='if set, start trader in debug mode')
+    parser.add_argument('-u', '--ui', action='store_true', default=False, help='if True, start trader in terminal ui')
 
     return parser
 
@@ -206,7 +210,7 @@ def parse_freq_string(freq, std_freq_only=False):
 
     # 继续拆分main_freq与qty_part
     if len(main_freq) > 1:
-        maybe_qty = ''.join(re.findall('\d+', main_freq))
+        maybe_qty = ''.join(re.findall(r'\d+', main_freq))
         # 另外一种处理方法
         # qty_part = ''.join(list(filter(lambda x: x.isdigit(), main_freq)))
         qty_len = len(maybe_qty)
@@ -218,7 +222,7 @@ def parse_freq_string(freq, std_freq_only=False):
         return None, None, None
 
     if (main_freq == 'MIN') and not std_freq_only:
-        available_qty = [''.join(re.findall('\d+', freq_string)) for freq_string in TIME_FREQ_STRINGS]
+        available_qty = [''.join(re.findall(r'\d+', freq_string)) for freq_string in TIME_FREQ_STRINGS]
         available_qty = [int(item) for item in available_qty if len(item) > 0]
         qty_fitness = [qty % item for item in available_qty]
         min_qty = available_qty[qty_fitness.index(0)]
@@ -265,7 +269,7 @@ def next_main_freq(freq, direction='up'):
             return target_freq
 
 
-def retry(exception_to_check, tries=3, delay=1, backoff=2., mute=False, logger=None):
+def retry(exception_to_check, tries=3, delay=1., backoff=2., mute=False, logger=None):
     """一个装饰器，当被装饰的函数抛出异常时，反复重试直至次数耗尽，重试前等待并延长等待时间.
 
     Parameters
@@ -279,7 +283,7 @@ def retry(exception_to_check, tries=3, delay=1, backoff=2., mute=False, logger=N
     backoff: float
         延迟倍增乘数，每多一次重试延迟时间就延长该倍数
     mute: bool, Default: False
-        静默功能，True时不打印信息也不输出logger.warning, 只输出logger.info()
+        静默功能，True时不打印信息也不输出logger.warning, 只输出logger.debug()
     logger: logging.Logger 对象
         日志logger对象. 如果给出None, 则打印结果
     """
@@ -293,10 +297,16 @@ def retry(exception_to_check, tries=3, delay=1, backoff=2., mute=False, logger=N
                 try:
                     return f(*args, **kwargs)
                 except exception_to_check as e:
+                    exception_to_escape = [ValueError, TypeError, AttributeError, FileNotFoundError, PermissionError,]
+                    error_str = str(e)
+                    if ('没有访问该接口的权限' in error_str) or ('api init error' in error_str):
+                        raise e
+                    if e.__class__ in exception_to_escape:
+                        raise e
                     msg = f'Error in {f.__name__}: {e.__class__}:{str(e)}, Retrying in {mdelay} seconds...'
                     if mute:
                         if logger:
-                            logger.info(msg)
+                            logger.debug(msg)
                     else:
                         if logger:
                             logger.warning(msg)
@@ -760,16 +770,19 @@ def progress_bar(prog: int, total: int = 100, comments: str = ''):
     comments: str, optional
         需要显示在进度条中的文字信息
     """
+    column_width, _ = shutil.get_terminal_size()
+
     if total > 0:
         if prog > total:
             prog = total
         progress_str = f'\r \r[{PROGRESS_BAR[int(prog / total * 40)]}]' \
                        f'{prog}/{total}-{np.round(prog / total * 100, 1)}%  {comments}'
+        progress_str = adjust_string_length(progress_str, column_width)
         sys.stdout.write(progress_str)
         sys.stdout.flush()
 
 
-def get_current_tz_datetime(self, time_zone='local'):
+def get_current_timezone_datetime(time_zone='local'):
     """ 获取指定时区的当前时间，同时确保返回的时间是tz_naive的
 
     如果time_zone为'local', 获取当前时区的当前时间。
@@ -784,7 +797,7 @@ def get_current_tz_datetime(self, time_zone='local'):
         return pd.to_datetime('today')
     else:
         # create utc time and convert to time_zone time and remove time_zone information
-        dt = pd.to_datetime('now', utc=True).tz_convert(self.time_zone)
+        dt = pd.to_datetime('now', utc=True).tz_convert(time_zone)
         return pd.to_datetime(dt.tz_localize(None))
 
 
@@ -820,7 +833,8 @@ def maybe_trade_day(date):
     try:
         date = pd.to_datetime(date).floor(freq='d')
     except Exception:
-        raise ValueError('date is not a valid date time format, cannot be converted to timestamp')
+        msg = f'{date} is not a valid date time format, cannot be converted to timestamp'
+        raise ValueError(msg)
     if date.weekday() > 4:
         return False
     for m, d in zip(public_holidays[0], public_holidays[1]):
@@ -918,24 +932,32 @@ def is_market_trade_day(date, exchange: str = 'SSE'):
         _date = pd.to_datetime(date).floor(freq='d')
     except Exception as ex:
         ex.extra_info = f'{date} is not a valid date time format, cannot be converted to timestamp'
-        raise
+        raise ex
     if _date is None:
-        raise TypeError(f'{date} is not a valid date')
+        msg = f'{date} is not a valid date'
+        raise TypeError(msg)
     if not isinstance(exchange, str) and exchange in ['SSE', 'SZSE', 'CFFEX', 'SHFE', 'CZCE',
                                                       'DCE', 'INE', 'IB', 'XHKG']:
-        raise TypeError(f'exchange \'{exchange}\' is not a valid input')
+        msg = f'exchange \'{exchange}\' is not a valid input'
+        raise TypeError(msg)
     if qteasy.QT_TRADE_CALENDAR is not None:
         try:
             exchange_trade_cal = qteasy.QT_TRADE_CALENDAR.loc[exchange]
         except KeyError as e:
-            raise KeyError(f'Trade Calender for exchange: {e} was not properly downloaded, please refill data')
+            e.extra_info = f'Trade Calender for exchange: {exchange} is not downloaded, please refill data'
+            raise e
         try:
             is_open = exchange_trade_cal.loc[_date].is_open
-        except KeyError:
-            raise ValueError(f'The date {_date} is out of trade calendar range, please refill data')
+        except KeyError as e:
+            e.extra_info = f'Trade Calendar for exchange: {exchange} is not available, please refill data'
+            raise e
         return is_open == 1
     else:
-        warnings.warn('Trade Calendar is not available, will use maybe_trade_day instead to check trade day')
+        msg = 'Trade Calendar is not available,  will use maybe_trade_day instead to check trade day\n' \
+                'Trade Calendar can be downloaded to DataSource, Use:\n' \
+                'qteasy.refill_data_source(tables="basics")\n' \
+                'see more details in qteasy docs: https://qteasy.readthedocs.io/zh/latest/'
+        warnings.warn(msg, RuntimeWarning)
         return maybe_trade_day(_date)
 
 
@@ -960,17 +982,20 @@ def last_known_market_trade_day(exchange: str = 'SSE'):
     """
     if not isinstance(exchange, str) and exchange in ['SSE', 'SZSE', 'CFFEX', 'SHFE', 'CZCE',
                                                       'DCE', 'INE', 'IB', 'XHKG']:
-        raise TypeError(f'exchange \'{exchange}\' is not a valid input')
+        msg = f'exchange \'{exchange}\' is not a valid input'
+        raise TypeError(msg)
     if qteasy.QT_TRADE_CALENDAR is not None:
         try:
             exchange_trade_cal = qteasy.QT_TRADE_CALENDAR.loc[exchange]
         except KeyError as e:
-            raise KeyError(f'Trade Calender for exchange: {e} was not properly downloaded, please refill data')
+            msg = f'Trade Calender for exchange: {e} was not properly downloaded, please refill data'
+            raise KeyError(msg)
         return exchange_trade_cal[exchange_trade_cal.is_open == 1].index.max()
     else:
-        raise RuntimeError('Trade Calendar is not available, please download basic data into DataSource, Use:\n'
-                           'qteasy.refill_data_source(tables="basics")\n'
-                           'see more details in qteasy docs')
+        msg = 'Trade Calendar is not available, please download basic data into DataSource, Use:\n' \
+               'qteasy.refill_data_source(tables="basics")\n' \
+               'see more details in qteasy docs: https://qteasy.readthedocs.io/zh/latest/'
+        raise RuntimeError(msg)
 
 
 @lru_cache(maxsize=16)
@@ -1017,9 +1042,10 @@ def prev_market_trade_day(date, exchange='SSE'):
         pretrade_date = exchange_trade_cal.loc[_date].pretrade_date
         return pd.to_datetime(pretrade_date)
     else:
-        raise RuntimeError('Trade Calendar is not available, please download basic data into DataSource, Use:\n'
-                           'qteasy.refill_data_source(tables="basics")\n'
-                           'see more details in qteasy docs')
+        msg = 'Trade Calendar is not available, please download basic data into DataSource, Use:\n' \
+                'qteasy.refill_data_source(tables="basics")\n' \
+                'see more details in qteasy docs: https://qteasy.readthedocs.io/zh/latest/'
+        raise RuntimeError(msg)
 
 
 @lru_cache(maxsize=16)
@@ -1164,9 +1190,15 @@ def list_truncate(lst, trunc_size):
     >>> [[1,2,3,4], [5,6,7,8], [9,0]]
     """
 
-    assert isinstance(lst, list), f'first parameter should be a list, got {type(lst)}'
-    assert isinstance(trunc_size, int), f'second parameter should be an integer larger than 0'
-    assert trunc_size > 0, f'second parameter should be an integer larger than 0, got {trunc_size}'
+    if not isinstance(lst, list):
+        msg = f'first parameter should be a list, got {type(lst)}'
+        raise TypeError(msg)
+    if not isinstance(trunc_size, int):
+        msg = f'second parameter should be an integer larger than 0'
+        raise TypeError(msg)
+    if not trunc_size > 0:
+        msg = f'second parameter should be an integer larger than 0, got {trunc_size}'
+        raise ValueError(msg)
     total = len(lst)
     if total <= trunc_size:
         return [lst]
@@ -1375,14 +1407,14 @@ def match_ts_code(code: str, asset_types='all', match_full_name=False):
     code_matched = {}
     count = 0
     import re
-    if re.match('[0-9A-Z]+\.[a-zA-Z]+$', code):
+    if re.match(r'[0-9A-Z]+\.[a-zA-Z]+$', code):
         # if code like "000100.SH"
         for at in asset_types:
             basic = asset_type_basics[at]
             ts_code = basic.loc[basic.index == code].name.to_dict()
             count += len(ts_code)
             code_matched.update({at: ts_code})
-    elif re.match('[0-9A-Z]+$', code):
+    elif re.match(r'[0-9A-Z]+$', code):
         # if code like all number inputs
         for at in asset_types:
             basic = asset_type_basics[at]
@@ -1874,7 +1906,7 @@ def reindent(s, num_spaces=4):
     return s
 
 
-def truncate_string(s, n, padder='.'):  # to be deprecated
+def truncate_string(s, n, padder='.') -> str:  # to be deprecated
     """ to be deprecated, 调整字符串为指定长度，为了保证兼容性，暂时保留此函数
     以后使用adjust_string_length代替
 
@@ -1904,7 +1936,7 @@ def truncate_string(s, n, padder='.'):  # to be deprecated
     return adjust_string_length(s, n, ellipsis=padder)
 
 
-def adjust_string_length(s, n, ellipsis='.', padder=' ', hans_aware=False, padding='right', format_tags=False):
+def adjust_string_length(s, n, ellipsis='.', padder=' ', hans_aware=False, padding='right', format_tags=False) -> str:
     """ 调整字符串为指定长度，如果字符串过长则将其截短，并在末尾添加省略号提示，
         如果字符串过短则在末尾添加空格补齐长度
 
@@ -1958,17 +1990,23 @@ def adjust_string_length(s, n, ellipsis='.', padder=' ', hans_aware=False, paddi
     cut_off_proportion = 0.7
 
     if not isinstance(s, str):
-        raise TypeError(f'the first argument should be a string, got {type(s)} instead')
+        msg = f'the first argument should be a string, got {type(s)} instead'
+        raise TypeError(msg)
     if not isinstance(n, int):
-        raise TypeError(f'the second argument should be an integer, got {type(n)} instead')
+        msg = f'the second argument should be an integer, got {type(n)} instead'
+        raise TypeError(msg)
     if not isinstance(ellipsis, str):
-        raise TypeError(f'the padder should be a character, got {type(ellipsis)} instead')
+        msg = f'the padder should be a character, got {type(ellipsis)} instead'
+        raise TypeError(msg)
     if not len(ellipsis) == 1:
-        raise ValueError(f'the padder should be a single character, got {len(ellipsis)} characters')
+        msg = f'the padder should be a single character, got {len(ellipsis)} characters'
+        raise ValueError(msg)
     if not isinstance(padder, str):
-        raise TypeError(f'the padder should be a character, got {type(padder)} instead')
+        msg = f'the padder should be a character, got {type(padder)} instead'
+        raise TypeError(msg)
     if n < 1:
-        raise ValueError(f'the expected length should be larger than 0, got {n}')
+        msg = f'the expected length should be larger than 0, got {n}'
+        raise ValueError(msg)
 
     length = len(s)
     if hans_aware:
@@ -2143,7 +2181,8 @@ def _count_hans(s: str):
     """
     # for loop is faster than list comprehension and regex
     if not isinstance(s, str):
-        raise TypeError(f'the argument should be a string, got {type(s)} instead')
+        msg = f'should be a string, got {type(s)} instead'
+        raise TypeError(msg)
     hans_total = 0
     for char in s:
         if '\u4e00' <= char <= '\u9fff':
