@@ -9,15 +9,16 @@
 #   qteasy.
 # ======================================
 import unittest
-
+import sys
+import pandas as pd
+import numba as nb
 import qteasy as qt
 import numpy as np
-from qteasy.tsfuncs import stock_basic
 
 from qteasy.tafuncs import bbands
 from qteasy.tafuncs import sma
 
-from qteasy.strategy import BaseStrategy, RuleIterator, GeneralStg
+from qteasy.strategy import RuleIterator, GeneralStg
 
 
 class TestLSStrategy(RuleIterator):
@@ -39,7 +40,7 @@ class TestLSStrategy(RuleIterator):
                          description='test long/short strategy',
                          par_count=2,
                          par_types='discr, conti',
-                         par_range=([1, 20], [2, 20]),
+                         par_range=([2, 20], [2, 20]),
                          strategy_data_types='close, open, high, low',
                          data_freq='d',
                          window_length=5)
@@ -55,7 +56,7 @@ class TestLSStrategy(RuleIterator):
         ma = sma(avg, n)
         if r is not None:
             # 处理参考数据生成信号并返回
-            ref_price = r[-1, 0]  # 当天的参考数据，r[-1
+            ref_price = r[-1, 0]  # 当天的参考数据，r[-1]
             if ma[-1] < ref_price:
                 return 0
             else:
@@ -258,6 +259,13 @@ class TestQT(unittest.TestCase):
         self.op = qt.Operator(strategies=['dma', 'macd'])
         print('  START TO TEST QT GENERAL OPERATIONS\n'
               '=======================================')
+        print(' test environment information')
+        print(f'  python version: {sys.version}')
+        print(f'  qteasy version: {qt.__version__}')
+        print(f'  qteasy root path: {qt.QT_ROOT_PATH}')
+        print(f'  numpy version: {np.__version__}')
+        print(f'  numba version: {nb.__version__}')
+        print(f'  pandas version: {pd.__version__}')
         self.op.set_parameter('dma', opt_tag=1, par_range=[(10, 250), (10, 250), (10, 250)])
         self.op.set_parameter('macd', opt_tag=1, par_range=[(10, 250), (10, 250), (10, 250)])
         self.op.signal_type = 'pt'
@@ -352,6 +360,9 @@ class TestQT(unittest.TestCase):
         qt.configuration(default=True)
         print(f'configuration with info=True, verbose=True\n')
         qt.configuration(default=True, verbose=True)
+        print(f'configuration with config_key')
+        qt.configuration('mode, time_zone, asset_pool')
+        qt.configuration(['mode', 'time_zone', 'asset_pool'])
 
     def test_run_mode_0(self):
         """测试策略的实时信号生成模式"""
@@ -374,25 +385,44 @@ class TestQT(unittest.TestCase):
         """测试策略的回测模式，结果可视化但不打印"""
         print(f'test plot with no buy-sell points and position indicators')
         qt.configuration(up_to=1, default=True)
-        qt.run(self.op,
-               mode=1,
-               trade_batch_size=1,
-               visual=True,
-               trade_log=False,
-               buy_sell_points=False,
-               show_positions=False,
-               invest_cash_dates='20070616')
+        res = qt.run(
+                self.op,
+                mode=1,
+                trade_batch_size=1,
+                visual=True,
+                trade_log=False,
+                buy_sell_points=False,
+                show_positions=False,
+                invest_cash_dates='20070616',
+        )
+        self.assertIsInstance(res, dict)
+        self.assertIsNone(res['trade_log'])
 
         print(f'test plot with both buy-sell points and position indicators')
         qt.configuration(up_to=1, default=True)
-        qt.run(self.op,
-               mode=1,
-               trade_batch_size=1,
-               visual=True,
-               trade_log=False,
-               buy_sell_points=True,
-               show_positions=True,
-               invest_cash_dates='20070604')
+        res = qt.run(
+                self.op,
+                mode=1,
+                trade_batch_size=1,
+                invest_start='20070604',
+                invest_end='20190329',
+                invest_cash_amounts=[100_000],
+                visual=True,
+                trade_log=True,
+                buy_sell_points=True,
+                show_positions=True,
+                invest_cash_dates='20070604',
+        )
+        self.assertIsInstance(res, dict)
+        self.assertIsNotNone(res['trade_log'])
+        self.assertIsInstance(res['report'], str)
+        print(res['trade_log'])
+        print(res['report'])
+        print(res['trade_record'])
+        print(res['final_value'])
+        print(res['info'])
+        print(res['sharp'])
+        self.assertAlmostEqual(res['final_value'], 341175.59, 0)
 
     def test_run_mode_2_montecarlo(self):
         """测试策略的优化模式，使用蒙特卡洛寻优"""
@@ -936,7 +966,7 @@ class TestQT(unittest.TestCase):
                     '000300': (20, 6)}
         par_stg2 = ()
         for op in [op_batch, op_stepwise]:
-            op.set_parameter(0, pars=par_stg1, opt_tag=1, par_range=([1, 20], [2, 100]))
+            op.set_parameter(0, pars=par_stg1, opt_tag=1, par_range=([2, 20], [2, 100]))
             op.set_parameter(1, pars=par_stg2, opt_tag=1)
 
         qt.configure(
@@ -1026,4 +1056,4 @@ if __name__ == '__main__':
     qt.refill_data_source(qt.QT_DATA_SOURCE, tables='stock_hourly', start_date='20160101', end_date='20161231',
                           code_range=['000001', '000002', '000005', '000006', '000007', '000918', '000819',
                                       '000899'])
-    unittest.main()
\ No newline at end of file
+    unittest.main()
