@@ -10,6 +10,7 @@
 
 import unittest
 import time
+import os
 
 from threading import Thread
 
@@ -59,20 +60,13 @@ class TestTrader(unittest.TestCase):
             'opti_start':           '2018-01-01',
         }
         # 创建测试数据源
-        data_test_dir = 'data_test/'
+        data_test_dir = '../qteasy/data_test/'
         # 创建一个专用的测试数据源，以免与已有的文件混淆，不需要测试所有的数据源，因为相关测试在test_datasource中已经完成
-        test_ds = DataSource('file', file_type='hdf', file_loc=data_test_dir)
-        # test_ds = DataSource(
-        #         'db',
-        #         host=QT_CONFIG['test_db_host'],
-        #         port=QT_CONFIG['test_db_port'],
-        #         user=QT_CONFIG['test_db_user'],
-        #         password=QT_CONFIG['test_db_password'],
-        #         db_name=QT_CONFIG['test_db_name']
-        # )
+        test_ds = DataSource('file', file_type='csv', file_loc=data_test_dir)
         test_ds.reconnect()
         # 清空测试数据源中的所有相关表格数据
-        for table in ['sys_op_live_accounts', 'sys_op_positions', 'sys_op_trade_orders', 'sys_op_trade_results']:
+        for table in ['sys_op_live_accounts', 'sys_op_positions', 'sys_op_trade_orders', 'sys_op_trade_results',
+                      'stock_daily']:
             if test_ds.table_data_exists(table):
                 test_ds.drop_table_data(table)
         # 创建一个ID=1的账户
@@ -87,20 +81,7 @@ class TestTrader(unittest.TestCase):
         update_position(position_id=3, data_source=test_ds, qty_change=300, available_qty_change=300)
         update_position(position_id=4, data_source=test_ds, qty_change=200, available_qty_change=100)
 
-        # 下载测试所需的基本数据
-        print('Downloading test data...')
-        # TODO: 这里如果设置parallel=True，会导致下载数据时死锁，原因不明
-        test_ds.refill_local_source(
-                tables='stock_daily',
-                symbols='000001.SZ, 000002.SZ, 000004.SZ, 000005.SZ, 000006.SZ, 000007.SZ',
-                start_date='2023-06-04',
-                end_date='2023-07-22',
-                freqs='D',
-                asset_types='E',
-                dtypes='close',
-                parallel=False,
-        )
-        self.stoppage = 1.5
+        self.stoppage = 0.5
         # 添加测试交易订单以及交易结果
         print('Adding test trade orders and results...')
         parsed_signals_batch = (
@@ -253,6 +234,241 @@ class TestTrader(unittest.TestCase):
                 datasource=test_ds,
                 debug=False,
         )
+        self.ts.init_trade_log_file()
+        self.ts.init_system_logger()
+
+    def test_system_logging(self):
+        """ test all functions related to system logging
+
+        """
+        ts = self.ts
+        # remove test sys_log_file
+        sys_log_file_path = ts.sys_log_file_path_name
+        os.remove(sys_log_file_path)
+        self.assertFalse(os.path.exists(sys_log_file_path))
+        ts.init_system_logger()
+        print(f'test log to system log file')
+        logger = ts.live_sys_logger
+        logger.info('test info message')
+        logger.warning('test warning message')
+        logger.error('test error message')
+        logger.critical('test critical message')
+        self.assertTrue(os.path.exists(sys_log_file_path))
+        with open(sys_log_file_path, 'r') as f:
+            lines = f.readlines()
+            print(f'lines written to system log file: \n{lines}')
+            self.assertEqual(len(lines), 4)
+            self.assertEqual(lines[0], 'test info message\n')
+            self.assertEqual(lines[1], 'test warning message\n')
+            self.assertEqual(lines[2], 'test error message\n')
+            self.assertEqual(lines[3], 'test critical message\n')
+
+        print(f'test reading contents from system log file')
+        log_content = ts.read_sys_log()
+        self.assertIsInstance(log_content, list)
+        self.assertEqual(log_content, lines)
+
+        log_content = ts.read_sys_log(row_count=2)
+        self.assertIsInstance(log_content, list)
+        self.assertEqual(log_content, lines[-2:])
+
+        log_content = ts.read_sys_log(row_count=20)
+        self.assertIsInstance(log_content, list)
+        self.assertEqual(log_content, lines)
+
+        log_content = ts.read_sys_log(row_count=0)
+        self.assertIsInstance(log_content, list)
+        self.assertEqual(log_content, lines)
+
+        log_content = ts.read_sys_log(row_count=-1)
+        self.assertIsInstance(log_content, list)
+        self.assertEqual(log_content, lines)
+
+        # remove the log file and check if it is removed
+        os.remove(sys_log_file_path)
+        self.assertFalse(os.path.exists(sys_log_file_path))
+
+    def test_trade_logging(self):
+        """ test all documents related to trade logging file operations
+        renew_trade_log_file
+
+        """
+
+        print(f'test property trade_log_file_is_valid')
+        ts = self.ts
+        trade_log_file_path_name = ts.trade_log_file_path_name
+        # remove the log file
+        os.remove(trade_log_file_path_name)
+        self.assertFalse(ts.trade_log_file_is_valid)
+        self.assertFalse(os.path.exists(trade_log_file_path_name))
+
+        self.assertFalse(os.path.exists(trade_log_file_path_name))
+        res = ts.renew_trade_log_file()
+        self.assertTrue(os.path.exists(trade_log_file_path_name))
+        self.assertEqual(res, ts.trade_log_file_path_name)
+        # remove the file and re-init
+        log_file_path_name = ts.trade_log_file_path_name
+        self.assertTrue(os.path.exists(log_file_path_name))
+        self.assertTrue(ts.trade_log_file_is_valid)
+
+        # remove the log file
+        os.remove(log_file_path_name)
+        self.assertFalse(ts.trade_log_file_is_valid)
+        self.assertFalse(os.path.exists(log_file_path_name))
+
+        # create a file with wrong format
+        import csv
+        with open(log_file_path_name, 'a') as f:
+            writer = csv.writer(f)
+            writer.writerow('wrong content!')
+
+        self.assertTrue(os.path.exists(log_file_path_name))
+        self.assertFalse(ts.trade_log_file_is_valid)
+
+        print(f'test function renew_trade_log_file')
+        ts.renew_trade_log_file()
+        self.assertTrue(ts.trade_log_file_is_valid)
+        self.assertTrue(os.path.exists(log_file_path_name))
+        import csv
+        with open(log_file_path_name, 'r') as f:
+            reader = csv.reader(f)
+            rows = [row for row in reader]
+
+            # there should be only one row, the header row
+            self.assertEqual(len(rows), 1)
+            self.assertEqual(rows[0], ts.trade_log_file_headers)
+
+        print(f'test function write_log_file')
+        log_content = {
+            'position_id': 1,
+            'order_id': 1,
+            'symbol': '000001.SZ',
+            'name': '招商银行',
+            'qty_change': 100,
+            'qty': 100,
+        }
+        ts.write_log_file(**log_content)
+        with open(log_file_path_name, 'r') as f:
+            reader = csv.reader(f)
+            rows = [row for row in reader]
+
+            # there should be only one row, the header row
+            self.assertEqual(len(rows), 2)
+            # compare items one by one to see if they match
+            row = rows[1]
+            self.assertEqual(row[3], '1')
+            self.assertEqual(row[4], '000001.SZ')
+            self.assertEqual(row[5], '招商银行')
+            self.assertEqual(row[6], '')
+            self.assertEqual(row[11], '100.000')
+            self.assertEqual(row[12], '100.000')
+            self.assertEqual(row[2], '1')
+
+        print(f'test writing multiple rows in the file and verify every row')
+        log_content = {
+            'position_id': 1,
+            'order_id': 2,
+            'symbol': '000651.SZ',
+            'name': '格力电器',
+            'qty_change': 200,
+            'qty': 200,
+            'holding_cost': 70.5,
+            'reason': 'order',
+            'position_type': 'long',
+        }
+        ts.write_log_file(**log_content)
+        log_content = {
+            'position_id': 1,
+            'order_id': 3,
+            'symbol': '000004.SZ',
+            'name': '国农科技',
+            'qty_change': -200,
+            'qty': 100,
+            'holding_cost': 80.5,
+            'reason': 'order',
+        }
+        ts.write_log_file(**log_content)
+        log_content = {
+            'reason': 'manual',
+            'cash_change': 10000.0,
+            'cash': 100000.0,
+            'available_cash_change': 10000.0,
+            'available_cash': 100000.0,
+        }
+        ts.write_log_file(**log_content)
+
+        with open(log_file_path_name, 'r') as f:
+            reader = csv.reader(f)
+            rows = [row for row in reader]
+
+            # there should be only one row, the header row
+            self.assertEqual(len(rows), 5)
+            # compare items one by one to see if they match
+            row = rows[1]
+            self.assertNotEqual(row[0], '')
+            self.assertEqual(row[2], '1')
+            self.assertEqual(row[3], '1')
+            self.assertEqual(row[4], '000001.SZ')
+            self.assertEqual(row[5], '招商银行')
+            self.assertEqual(row[6], '')
+            self.assertEqual(row[11], '100.000')
+            self.assertEqual(row[12], '100.000')
+            row = rows[2]
+            self.assertNotEqual(row[0], '')
+            self.assertEqual(row[1], 'order')
+            self.assertEqual(row[2], '2')
+            self.assertEqual(row[3], '1')
+            self.assertEqual(row[4], '000651.SZ')
+            self.assertEqual(row[5], '格力电器')
+            self.assertEqual(row[6], 'long')
+            self.assertEqual(row[11], '200.000')
+            self.assertEqual(row[12], '200.000')
+            self.assertEqual(row[16], '70.500')
+            row = rows[3]
+            self.assertNotEqual(row[0], '')
+            self.assertEqual(row[1], 'order')
+            self.assertEqual(row[2], '3')
+            self.assertEqual(row[3], '1')
+            self.assertEqual(row[4], '000004.SZ')
+            self.assertEqual(row[5], '国农科技')
+            self.assertEqual(row[6], '')
+            self.assertEqual(row[11], '-200.000')
+            self.assertEqual(row[12], '100.000')
+            self.assertEqual(row[16], '80.500')
+            row = rows[4]
+            self.assertNotEqual(row[0], '')
+            self.assertEqual(row[1], 'manual')
+            self.assertEqual(row[2], '')
+            self.assertEqual(row[4], '')
+            self.assertEqual(row[17], '10000.000')
+            self.assertEqual(row[18], '100000.000')
+            self.assertEqual(row[19], '10000.000')
+            self.assertEqual(row[20], '100000.000')
+
+        # remove the log file and check if it is removed
+        os.remove(log_file_path_name)
+        self.assertFalse(ts.trade_log_file_is_valid)
+
+        # if a wrong file is stored with correct name, it should be checked,
+        # removed and a new correct file should be created
+        # write a csv file with wrong header
+        with open(log_file_path_name, mode='w', encoding='utf-8') as f:
+            writer = csv.writer(f)
+            row = ['some', 'random', 'but', 'wrong', 'headers']
+            writer.writerow(row)
+
+        self.assertFalse(ts.trade_log_file_is_valid)
+        # use ts.renew_trade_log_file will remove wrong file and create correct one
+        ts.renew_trade_log_file()
+        self.assertTrue(ts.trade_log_file_is_valid)
+
+        print(f'test reading dataframe from trade log files')
+        df = ts.read_trade_log()
+        self.assertIsInstance(df, pd.DataFrame)
+        print(f'trade log dataframe: \n{df}')
+
+        # remove the log file and check if it is removed
+        os.remove(log_file_path_name)
 
     def test_trader_status(self):
         """Test class Trader"""
@@ -260,7 +476,13 @@ class TestTrader(unittest.TestCase):
         self.assertIsInstance(ts, Trader)
         Thread(target=ts.run).start()
         time.sleep(self.stoppage)
-        self.assertEqual(ts.status, 'sleeping')
+        if self.ts.is_market_open:
+            self.assertEqual(ts.status, 'running')
+            prev_status = 'running'
+        else:
+            self.assertEqual(ts.status, 'sleeping')
+            prev_status = 'sleeping'
+
         print(f'\ncurrent status: {ts.status}')
         ts.add_task('wakeup')
         time.sleep(self.stoppage)
@@ -328,6 +550,7 @@ class TestTrader(unittest.TestCase):
     def test_trader_properties_methods(self):
         """Test function run_task"""
         ts = self.ts
+        ts.renew_trade_log_file()
         self.assertIsInstance(ts, Trader)
         self.assertEqual(ts.status, 'stopped')
         ts.run_task('start')
@@ -376,38 +599,38 @@ class TestTrader(unittest.TestCase):
                                                            'submitted_time', 'status'])
         # test manual change of cashes and positions
         self.assertEqual(ts.account_cash, (73905.0, 73905.0, 100000.0))
-        ts._change_cash(10000.0)
+        ts.manual_change_cash(10000.0)
         self.assertEqual(ts.account_cash, (83905.0, 83905.0, 110000.0))
-        ts._change_cash(-10000.0)
+        ts.manual_change_cash(-10000.0)
         self.assertEqual(ts.account_cash, (73905.0, 73905.0, 100000.0))
         # test too large cash change
-        ts._change_cash(-100000.0)
+        ts.manual_change_cash(-100000.0)
         self.assertEqual(ts.account_cash, (73905.0, 73905.0, 100000.0))
 
         self.assertTrue(np.allclose(ts.account_positions['qty'], [100.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [100.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
-        ts._change_position('000001.SZ', 200.0, 10.0)
+        ts.manual_change_position('000001.SZ', 200.0, 10.0)
         self.assertTrue(np.allclose(ts.account_positions['qty'], [300.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [300.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
-        ts._change_position('000001.SZ', -100.0, 10.0)
+        ts.manual_change_position('000001.SZ', -100.0, 10.0)
         self.assertTrue(np.allclose(ts.account_positions['qty'], [200.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [200.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
-        ts._change_position('000001.SZ', -100.0, 10.0, 'long')
+        ts.manual_change_position('000001.SZ', -100.0, 10.0, 'long')
         self.assertTrue(np.allclose(ts.account_positions['qty'], [100.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [100.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
         # wrong side of position change will be ignored
-        ts._change_position('000001.SZ', -100.0, 10.0, 'short')
+        ts.manual_change_position('000001.SZ', -100.0, 10.0, 'short')
         self.assertTrue(np.allclose(ts.account_positions['qty'], [100.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [100.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
         # the other side of position change can be done when this side is cleared
-        ts._change_position('000001.SZ', -100.0, 10.0, 'long')
+        ts.manual_change_position('000001.SZ', -100.0, 10.0, 'long')
         self.assertTrue(np.allclose(ts.account_positions['qty'], [0.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [0.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
-        ts._change_position('000001.SZ', 100.0, 10.0, 'short')
+        ts.manual_change_position('000001.SZ', 100.0, 10.0, 'short')
         self.assertTrue(np.allclose(ts.account_positions['qty'], [-100.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [-100.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
         # if reduced qty is larger than current qty, the change will be ignored
-        ts._change_position('000001.SZ', -200.0, 10.0, 'short')
+        ts.manual_change_position('000001.SZ', -200.0, 10.0, 'short')
         self.assertTrue(np.allclose(ts.account_positions['qty'], [-100.0, 100.0, 200.0, 200.0, 400.0, 200.0]))
         self.assertTrue(np.allclose(ts.account_positions['available_qty'], [-100.0, 100.0, 200.0, 100.0, 400.0, 200.0]))
 
@@ -424,22 +647,36 @@ class TestTrader(unittest.TestCase):
         print('added task start')
         print(f'trader status: {ts.status}')
         print(f'broker status: {ts.broker.status}')
-        self.assertEqual(ts.status, 'sleeping')
-        self.assertEqual(ts.broker.status, 'init')
+        # 新的trader创建后，如果当前是交易时段，status为running，否则为sleeping，因此这里的status可能是running或者sleeping，需要根据market_open判断
+        if self.ts.is_market_open:
+            self.assertEqual(ts.status, 'running')
+            self.assertEqual(ts.broker.status, 'running')
+        else:
+            self.assertEqual(ts.status, 'sleeping')
+            self.assertEqual(ts.broker.status, 'init')
         ts.add_task('pre_open')
         time.sleep(self.stoppage)
         print('added task pre_open')
         print(f'trader status: {ts.status}')
         print(f'broker status: {ts.broker.status}')
-        self.assertEqual(ts.status, 'sleeping')
-        self.assertEqual(ts.broker.status, 'init')
+        if self.ts.is_market_open:
+            self.assertEqual(ts.status, 'running')
+            self.assertEqual(ts.broker.status, 'running')
+            prev_status = 'running'
+            broker_prev_status = 'running'
+        else:
+            self.assertEqual(ts.status, 'sleeping')
+            self.assertEqual(ts.broker.status, 'init')
+            prev_status = 'sleeping'
+            broker_prev_status = 'init'
+
         ts.add_task('open_market')
         time.sleep(self.stoppage)
         print('added task open_market')
         print(f'trader status: {ts.status}')
         print(f'broker status: {ts.broker.status}')
-        self.assertEqual(ts.status, 'running')
-        self.assertEqual(ts.broker.status, 'running')
+        self.assertEqual(ts.status, prev_status)
+        self.assertEqual(ts.broker.status, broker_prev_status)
         ts.add_task('run_strategy', {'strategy_ids': ['macd']})
         time.sleep(self.stoppage)
         print('added task run_strategy - macd')
@@ -521,7 +758,7 @@ class TestTrader(unittest.TestCase):
 
         # 1, use trader._check_trade_day(sim_date) to simulate a trade day or non-trade day
         # 2, use trader._initialize_schedule(sim_time) to generate task agenda at a simulated time
-        # 3, use trader._add_task_from_agenda(sim_time) to add task from agenda at a simulated time
+        # 3, use trader._add_task_from_schedule(sim_time) to add task from agenda at a simulated time
 
         import datetime as dt
 
@@ -539,7 +776,7 @@ class TestTrader(unittest.TestCase):
         sim_time = dt.time(0, 0, 0)  # midnight
         ts._check_trade_day(sim_date)
         ts._initialize_schedule(sim_time)
-        ts._add_task_from_agenda(sim_time)
+        ts._add_task_from_schedule(sim_time)
 
         print('\n========generated task agenda in a non-trade day========\n')
         print(f'trader status: {ts.status}')
@@ -548,7 +785,7 @@ class TestTrader(unittest.TestCase):
         print(f'task daily agenda: {ts.task_daily_schedule}')
         self.assertEqual(ts.status, 'sleeping')
         self.assertEqual(ts.broker.status, 'init')
-        self.assertEqual(ts.is_trade_day, False)
+        self.assertEqual(ts.is_trade_day, ts.is_trade_day)
         self.assertEqual(ts.task_daily_schedule, [])
 
         # generate task agenda in a trade day and complete agenda will be generated depending on generate time
@@ -694,7 +931,7 @@ class TestTrader(unittest.TestCase):
         for sim_time in test_sim_times:
             print(f'\n=========simulating time: {sim_time}=========\n')
             print(f'\n=========current task agenda: {ts.task_daily_schedule[0]}=========\n')
-            ts._add_task_from_agenda(sim_time)
+            ts._add_task_from_schedule(sim_time)
             # waite 1 second for orders to be generated
             time.sleep(2)
             print(f'current trader status: {ts.status}')
@@ -717,4 +954,3 @@ class TestTrader(unittest.TestCase):
 
 if __name__ == '__main__':
     unittest.main()
-
